#!/opt/puppet/bin/ruby
#
# This script is designed to request classification from the configured Puppet
# Enterprise Console. This gives us the opportunity to inject classes or
# parameter settings before returning the final classification.
#
# This is a terrible idea, and you should never do it in production.
#
# puppet requires a home directory set
ENV['HOME'] = '/var/opt/lib/pe-puppet'

require 'yaml'
require 'syslog'
require 'net/https'
require 'puppet'

begin
  if File.read('/etc/puppetlabs/puppet/console.conf') =~ /^server = (\w+)/
    console = $1
  else
    raise ExecutionError, "Console parameter invalid"
  end

  Puppet.initialize_settings(['--confdir', '/etc/puppetlabs/puppet'])

  cert   = Puppet.settings[:hostcert]
  cacert = Puppet.settings[:localcacert]
  prvkey = Puppet.settings[:hostprivkey]

  uri    = URI.parse("https://#{console}/nodes/#{ARGV.first}")

  http = Net::HTTP.new(uri.host, uri.port)
  http.use_ssl = true
  http.verify_mode = OpenSSL::SSL::VERIFY_NONE

  store = OpenSSL::X509::Store.new
  store.add_cert(OpenSSL::X509::Certificate.new(File.read(cacert)))
  http.cert_store = store

  http.key  = OpenSSL::PKey::RSA.new(File.read(prvkey))
  http.cert = OpenSSL::X509::Certificate.new(File.read(cert))
  request   = Net::HTTP::Get.new(uri.request_uri)
  request['Accept'] = 'text/yaml'

  # Make the HTTPS request and parse the data structure returned
  data = YAML.load(http.request(request).body)

  # propagate the 'environment' parameter to a top-scope key
  if data['parameters'].include? 'environment'
    data['environment'] = data['parameters']['environment']
  end

  # return output to stdout
  puts data.to_yaml

rescue Exception => e
  Syslog.open('Puppet ENC', Syslog::LOG_PID | Syslog::LOG_CONS) do |syslog|
    syslog.warning "Configuration error for '#{ARGV.first}': #{e.message}"
  end

  # return error exit code
  exit 1
end
